=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2007-05-17 15:07:49 +0000
+++ bzrlib/commit.py	2007-05-21 14:14:36 +0000
@@ -299,8 +299,7 @@
 
             self._gather_parents()
             if len(self.parents) > 1 and self.specific_files:
-                raise NotImplementedError('selected-file commit of merges is not supported yet: files %r',
-                        self.specific_files)
+                raise errors.CannotCommitSelectedFileMerge(self.specific_files)
             
             self.builder = self.branch.get_commit_builder(self.parents,
                 self.config, timestamp, timezone, committer, revprops, rev_id)

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2007-04-26 09:07:38 +0000
+++ bzrlib/errors.py	2007-05-21 14:14:36 +0000
@@ -845,6 +845,16 @@
     _fmt = "No changes to commit"
 
 
+class CannotCommitSelectedFileMerge(BzrError):
+
+    _fmt = 'Selected-file commit of merges is not supported yet:'\
+        ' files %(files_str)s'
+
+    def __init__(self, files):
+        files_str = ', '.join(files)
+        BzrError.__init__(self, files=files, files_str=files_str)
+
+
 class UpgradeReadonly(BzrError):
 
     _fmt = "Upgrade URL cannot work with readonly URLs."

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2007-03-07 19:33:08 +0000
+++ bzrlib/tests/test_commit.py	2007-05-21 14:14:36 +0000
@@ -681,3 +681,17 @@
         repository.add_inventory = raise_
         self.assertRaises(errors.NoSuchFile, tree.commit, message_callback=cb)
         self.assertFalse(cb.called)
+
+    def test_selected_file_merge_commit(self):
+        """Ensure the correct error is raised"""
+        tree = self.make_branch_and_tree('foo')
+        # pending merge would turn into a left parent
+        tree.commit('commit 1')
+        tree.add_parent_tree_id('example')
+        self.build_tree(['foo/bar', 'foo/baz'])
+        tree.add(['bar', 'baz'])
+        err = self.assertRaises(errors.CannotCommitSelectedFileMerge,
+            tree.commit, 'commit 2', specific_files=['bar', 'baz'])
+        self.assertEqual(['bar', 'baz'], err.files)
+        self.assertEqual('Selected-file commit of merges is not supported'
+                         ' yet: files bar, baz', str(err))

